@@ -14,27 +14,32 @@
 
 import kfp.dsl as dsl
 import kfp
+from kubernetes.client.models import V1Toleration
 
 
-def main_coon(s: str):
+def main_coon():
     container_op = dsl.ContainerOp(
         name='main-coon',
         image='eu.gcr.io/second-capsule-253207/adlinear:latest',
         command=['python'],
         arguments=['main_coon.py']
     )
-    container_op.add_resource_limit("memory", '5G')
-    container_op.add_resource_limit("cpu", '3')
-    container_op.add_resource_request("memory", '5G')
-    container_op.add_resource_request("cpu", '3')
+    # Single job specification
+    container_op.add_resource_limit("memory", '2G')
+    container_op.add_resource_limit("cpu", '1')
+    container_op.add_resource_request("memory", '2G')
+    container_op.add_resource_request("cpu", '1')
+    container_op.add_toleration(
+        V1Toleration(key="dedicated", operator="Equal", value="standard-preemptible", effect="NoSchedule")
+    )
     return container_op
 
 
 @dsl.pipeline(name='main-coon')
 def pipeline():
-    loop_args = list(range(3))
-    with dsl.ParallelFor(loop_args, parallelism=10) as item:
-        main_coon(item)
+    loop_args = list(range(20))  # run 20 jobs
+    with dsl.ParallelFor(loop_args, parallelism=10) as _:  # On max 10 machines at a time
+        main_coon()
 
 
 if __name__ == '__main__':
